pub async fn join(
options: MeetingOptions,
meeting_id: MeetingId,
user_id: Option<UserId>,
) -> Result<(Vec<Vec<u8>>, Value)>Expand description
Join a meeting point.
When all participants have joined the meeting point the public keys of all participants are returned.
When the user identifier is not given then the user is the creator of the meeting point who has already been registered as a participant when creating the meeting.